m3e_loading_indicator library

A Flutter package providing Material 3 Expressive (M3E) shape morphing loading indicators.

Classes

M3EContainedLoadingIndicator
A Material Design contained loading indicator.
M3ELoadingIndicator
A Material Design loading indicator.
M3EMotion
Spring animation configuration for Material 3 Expressive components.
M3EPullToRefreshController
Controller for programmatically observing and managing the state of a M3EPullToRefreshIndicator.
M3EPullToRefreshIndicator
A Material 3 Expressive (M3E) Pull to Refresh Indicator.
M3EPullToRefreshStyle
Style configuration for M3EPullToRefreshIndicator.

Enums

M3EHapticFeedback
Haptic feedback intensity levels.
Shapes
Represents a collection of predefined geometric shapes.

Functions

applyHaptic(M3EHapticFeedback haptic) → void
Helper function to apply haptic feedback based on M3EHapticFeedback.
applyTypedHaptic(String type, double amplitude) → void
Dispatch a typed haptic event with a pre-computed amplitude (0.0–1.0).