M3EPullToRefreshController class

Controller for programmatically observing and managing the state of a M3EPullToRefreshIndicator.

Exposes distanceFraction, isRefreshing, isAnimating, and allows programmatically opening the header and triggering a refresh via refresh.

Inheritance

Properties

distanceFraction double
Distance percentage towards the refresh threshold.
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
isAnimating bool
Whether the indicator is currently performing a spring animation.
no setter
isRefreshing bool
Whether a refresh operation is currently executing.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
attach(Future<void> refreshCallback()) → void
Attaches a callback to handle programmatic refresh triggers.
detach() → void
Detaches the registered refresh callback.
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
refresh() Future<void>
Programmatically triggers the pull-to-refresh operation.
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() String
A string representation of this object.
inherited
updateState({required double distanceFraction, required bool isRefreshing, required bool isAnimating}) → void
Internal update method called by M3EPullToRefreshIndicator.

Operators

operator ==(Object other) bool
The equality operator.
inherited