Shapes enum

Represents a collection of predefined geometric shapes.

Each member of this enum defines a specific shape, identified by a unique integer value and represented by an SVG path data String. This allows for easy reference and rendering of various shapes.

Inheritance
Available extensions

Values

circle → const Shapes

A circle shape.

const Shapes(0, "M350 190C350 278.366 278.366 350 190 350C101.634 350 30 278.366 30 190C30 101.634 101.634 30 190 30C278.366 30 350 101.634 350 190Z")
square → const Shapes

A square shape.

const Shapes(1, "M350 202C350 246.717 350 269.076 342.978 286.812C332.813 312.485 312.485 332.813 286.812 342.978C269.076 350 246.717 350 202 350H178C133.283 350 110.924 350 93.1875 342.978C67.51…
slanted → const Shapes

A slanted or skewed rectangle shape.

const Shapes(2, "M45.7147 120.543C48.289 95.9642 49.5761 83.6748 54.3025 73.9777C61.142 59.9453 73.0768 49.1101 87.6278 43.7229C97.6833 40 109.933 40 134.432 40H258.137C287.764 40 302.578 40 313.…
arch → const Shapes

An arch shape.

const Shapes(3, "M345 293.727C345 299.96 345 303.076 344.689 305.696C342.259 326.14 326.14 342.259 305.696 344.689C303.076 345 299.96 345 293.727 345H86.2732C80.0405 345 76.9242 345 74.3043 344.6…
semicircle → const Shapes

A semicircle shape.

const Shapes(4, "M350 256.921C350 275.19 335.19 290 316.921 290L63.0794 290C44.8102 290 30 275.19 30 256.921L30 250C30 161.634 101.634 90 190 90C278.366 90 350 161.634 350 250V256.921Z")
oval → const Shapes

An oval shape.

const Shapes(5, "M271.309 271.309C201.705 340.913 108.877 360.935 63.9707 316.029C19.0648 271.123 39.0867 178.295 108.691 108.691C178.295 39.0867 271.123 19.0648 316.029 63.9707C360.935 108.877 3…
pill → const Shapes

A pill or capsule shape (a rectangle with semicircular ends).

const Shapes(6, "M116.116 71.7851C169.162 18.7383 255.168 18.7383 308.215 71.7851C361.262 124.832 361.262 210.838 308.215 263.884L263.884 308.215C210.838 361.262 124.832 361.262 71.7851 308.215C1…
triangle → const Shapes

A triangle shape.

const Shapes(7, "M136.461 98.2021C151.597 71.8217 159.165 58.6315 168.342 53.0594C181.648 44.9802 198.352 44.9802 211.658 53.0594C220.835 58.6315 228.403 71.8217 243.539 98.2021L325.309 240.72C34…
arrow → const Shapes

An arrow shape.

const Shapes(8, "M262.422 104.907C253.213 90.2936 243.84 75.4777 231.389 63.8739C218.938 52.2412 202.808 44.023 186.27 45.0937C171.748 46.0486 158.288 54.0932 147.662 64.5974C137.036 75.1015 128.…
fan → const Shapes

A fan shape.

const Shapes(9, "M40 87.3684C40 85.697 40 84.8613 40.0219 84.1547C40.7686 60.0969 60.0969 40.7686 84.1547 40.0219C84.8613 40 85.697 40 87.3684 40C96.2825 40 100.74 40 104.508 40.117C232.816 44.09…
diamond → const Shapes

A diamond shape.

const Shapes(10, "M247.442 306.481C230.606 328.514 222.188 339.53 212.466 344.548C198.383 351.817 181.617 351.817 167.534 344.548C157.812 339.53 149.394 328.514 132.558 306.481L76.646 233.308C66.…
clampShell → const Shapes
const Shapes(11, "M5 62C2 54 2 46 5 38C5 38 16 12 16 12C19 4 24 0 30 0C30 0 75 0 75 0C81 0 86 4 89 12C89 12 100 38 100 38C103 46 103 54 100 62C100 62 89 88 89 88C86 96 81 100 75 100C75 100 30 100…
pentagon → const Shapes

A pentagon shape.

const Shapes(12, "M155.064 49.459C176.093 34.1803 204.569 34.1803 225.598 49.459L322.926 120.171C343.955 135.45 352.754 162.532 344.722 187.253L307.546 301.668C299.514 326.39 276.476 343.127 250.…
gem → const Shapes

A gem or crystal shape.

const Shapes(13, "M133.415 65.7498C150.981 52.991 159.763 46.6116 169.124 43.4402C182.663 38.8533 197.337 38.8533 210.876 43.4402C220.237 46.6116 229.019 52.991 246.585 65.7498L286.083 94.4402C29…
verySunny → const Shapes

A shape resembling a very sunny day icon.

const Shapes(14, "M166.725 43.1869C177.261 25.6044 202.739 25.6044 213.275 43.1868L225.124 62.9597C231.268 73.2136 243.399 78.2385 254.995 75.3327L277.355 69.7294C297.237 64.7468 315.253 82.7627 …
sunny → const Shapes

A shape resembling a sunny day icon.

const Shapes(15, "M276.453 68.8118C286.405 69.4881 291.381 69.8263 295.404 71.5853C301.223 74.1305 305.87 78.7766 308.415 84.5965C310.174 88.6186 310.512 93.5948 311.188 103.547L312.732 126.259C3…
c4SidedCookie → const Shapes

A 4-sided cookie or gear-like shape.

const Shapes(16, "M230.389 50.473C293.109 23.2328 356.767 86.8908 329.527 149.611L325.023 159.981C316.707 179.13 316.707 200.87 325.023 220.019L329.527 230.389C356.767 293.109 293.109 356.767 230…
c6SidedCookie → const Shapes

A 6-sided cookie or gear-like shape.

const Shapes(17, "M134.186 54.5654C165.276 24.4782 214.724 24.4782 245.814 54.5654C255.328 63.7718 266.984 70.4811 279.738 74.0919C321.419 85.8924 346.142 128.586 335.552 170.473C332.312 183.291 …
c7SidedCookie → const Shapes

A 7-sided cookie or gear-like shape.

const Shapes(18, "M142.67 51.7842C146.243 48.6394 148.029 47.067 149.671 45.7954C173.425 27.4015 206.575 27.4015 230.329 45.7954C231.971 47.067 233.757 48.6394 237.33 51.7842C238.526 52.8372 239.…
c9SidedCookie → const Shapes

A 9-sided cookie or gear-like shape.

const Shapes(19, "M154.828 43.2756C156.574 41.8498 157.448 41.1369 158.245 40.535C177.03 26.3548 202.97 26.3548 221.755 40.535C222.552 41.1369 223.425 41.8498 225.172 43.2756C225.952 43.9121 226.…
c12SidedCookie → const Shapes

A 12-sided cookie or gear-like shape.

const Shapes(20, "M166.697 39.8458C167.238 39.3157 167.508 39.0506 167.743 38.8298C180.246 27.0567 199.754 27.0567 212.257 38.8298C212.492 39.0506 212.762 39.3157 213.303 39.8458C213.628 40.1639 …
l4LeafClover → const Shapes

A 4-leaf clover shape.

const Shapes(21, "M63.0014 190C49.8954 174.339 42 154.126 42 132.06C42 82.321 82.1131 42 131.595 42C153.99 42 174.466 50.2594 190.173 63.9131C205.843 50.2594 226.271 42 248.614 42C297.981 42 338 …
l8LeafClover → const Shapes

An 8-leaf clover shape.

const Shapes(22, "M338.584 189.998C364.427 238.164 344.902 281.771 295.066 295.061C281.771 344.902 238.164 364.422 189.998 338.584C141.831 364.427 98.2245 344.902 84.9337 295.066C35.0981 281.771 …
burst → const Shapes

A sharp, starburst shape.

const Shapes(23, "M187.293 26.6421C188.056 25.2785 188.437 24.5966 188.902 24.3108C189.575 23.8964 190.425 23.8964 191.098 24.3108C191.563 24.5966 191.944 25.2785 192.707 26.6421L218.917 73.4925C…
softBurst → const Shapes

A starburst shape with soft or rounded corners.

const Shapes(24, "M175.147 33.1508C181.983 22.2831 198.017 22.2831 204.853 33.1508L221.238 59.2009C225.731 66.3458 234.797 69.2506 242.692 66.0751L271.475 54.4972C283.482 49.6671 296.455 58.9613 …
boom → const Shapes

An explosive or 'boom' shape.

const Shapes(25, "M186.738 36.413C187.51 30.2399 187.896 27.1534 188.483 26.6019C189.337 25.7994 190.663 25.7994 191.517 26.6019C192.104 27.1534 192.49 30.2399 193.262 36.413L203.079 114.907C203.…
softBoom → const Shapes

An explosive shape with soft or rounded corners.

const Shapes(26, "M204.57 116.822C226.539 6.39254 153.487 6.39254 175.457 116.822C153.487 6.39254 85.9934 34.3433 148.549 127.966C85.9934 34.3433 34.3433 85.9934 127.966 148.549C34.3433 85.9934 6…
flower → const Shapes

A flower shape.

const Shapes(27, "M303.126 76.8625C291.251 64.988 264.194 70.8597 231.547 89.6813C221.771 53.2855 206.79 30 189.996 30C173.203 30 158.223 53.2841 148.447 89.6779C115.802 70.8581 88.7463 64.9874 7…
puffy → const Shapes

A puffy, cloud-like shape.

const Shapes(28, "M371.982 187.559C371.686 165.488 353.541 147.816 331.439 148.112C330.218 148.112 329.016 148.204 327.832 148.334C328.757 147.576 329.663 146.799 330.532 145.949C346.365 130.551 …
puffyDiamond → const Shapes

A puffy, diamond-like shape.

const Shapes(29, "M279.397 279.754C291.485 267.666 295.573 250.608 291.663 235.157C307.124 239.086 324.202 235.001 336.3 222.902C354.567 204.636 354.567 175.02 336.3 156.754C324.273 144.727 307.3…
ghostish → const Shapes

A shape resembling a cartoon ghost.

const Shapes(30, "M40 182.857C40 103.959 107.157 40 190 40C272.843 40 340 103.959 340 182.857L340 282.857C340 314.416 313.137 340 280 340C270.178 340 260.907 337.752 252.724 333.768C248.554 331.7…
pixelCircle → const Shapes

A pixelated circle shape.

const Shapes(31, "M253.556 34H126.444V54.2217H83.1111V80.2222H57.1111V126.444H34V253.556H57.1111V299.778H83.1111V325.777H126.444V346H253.556V325.777H296.889V299.778H322.889V253.556H346V126.444H32…
pixelTriangle → const Shapes

A pixelated triangle shape.

const Shapes(32, "M121.641 30H66V350H121.641V322.174H164.564V295.739H209.077V265.13H245.641V240.086H282.205V209.478H314V170.522H282.205V139.912H245.641V114.869H209.077V84.2609H164.564V57.8262H121…
bun → const Shapes

A shape resembling a bread bun.

const Shapes(33, "M38.875 113.322C38.875 69.5137 74.3887 34 118.197 34H261.803C305.611 34 341.125 69.5137 341.125 113.322C341.125 149.45 316.972 179.937 283.932 189.516C283.717 189.579 283.567 18…
heart → const Shapes

A heart shape.

const Shapes(34, "M281.1 47.134C259.439 47.134 240.113 57.3021 227.481 73.1973L190 114.513V114.379L152.519 73.0633C139.887 57.1681 120.561 47 98.8995 47C60.8478 47 30 78.3656 30 117.059C30 151.05…

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
polygon → RoundedPolygon
Returns the corresponding RoundedPolygon representation of this shape.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
svg String
The String representation of the shape as an SVG path. This data can be used by a renderer to draw the shape.
final
value int
The unique integer identifier for the shape.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Shapes>
A constant List of the values in this enum, in order of their declaration.